@@ -18,17 +18,19 @@ from kuwo import Config
 # ~/.config/kuwo and ~/.cache/kuwo need to be created at first time
 Config.check_first()
 _ = Config._
+from kuwo import Widgets
 from kuwo.Artists import Artists
 from kuwo.Lrc import Lrc
 from kuwo.MV import MV
+from kuwo.OSDLrc import OSDLrc
 from kuwo.Player import Player
 from kuwo.PlayList import PlayList
 from kuwo.Radio import Radio
 from kuwo.Search import Search
+from kuwo.Shortcut import Shortcut
 from kuwo.Themes import Themes
 from kuwo.TopCategories import TopCategories
 from kuwo.TopList import TopList
-from kuwo.Shortcut import Shortcut
 
 if Gtk.MAJOR_VERSION <= 3 and Gtk.MINOR_VERSION < 10:
     GObject.threads_init()
@@ -64,6 +66,8 @@ class App:
         box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         self.window.add(box)
 
+        self.osdlrc = OSDLrc(self)
+
         self.player = Player(self)
         box.pack_start(self.player, False, False, 0)
 
@@ -82,11 +86,11 @@ class App:
         self.window.show_all()
         # Make some changes after main window is shown.
         # Like hiding some unnecessory widgets.
-        self.lrc.after_init()
         self.artists.after_init()
         self.player.after_init()
         self.search.after_init()
         self.shortcut = Shortcut(self.player)
+        self.osdlrc.after_init()
 
     def on_app_shutdown(self, app):
         Config.dump_conf(self.conf)
@@ -149,40 +153,16 @@ class App:
         '''Switch to this widget in notebook.'''
         self.notebook.set_current_page(page)
 
-    def apply_css(self, widget, css, old_provider=None, overall=False):
-        '''Update CssProvider of this widget.'''
-        # CssProvider requires bytecode
-        style_provider = Gtk.CssProvider()
-        css_encoded = css.encode()
-        style_provider.load_from_data(css_encoded)
-        if overall:
-            Gtk.StyleContext.add_provider_for_screen(Gdk.Screen.get_default(),
-                    style_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
-            if old_provider:
-                Gtk.StyleContext.remove_provider_for_screen(
-                    Gdk.Screen.get_default(), style_provider)
-        else:
-            widget.get_style_context().add_provider(style_provider,
-                    Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
-            if old_provider:
-                widget.get_style_context().remove_provider(old_provider)
-        return style_provider
-
     def load_styles(self):
         '''Load default CssStyle.'''
         if Config.GTK_LE_36:
             css = '\n'.join([
-                # transition-property is not supported in Gtk3.4
-                #'GtkScrolledWindow.lrc_window {',
-                #    'transition-property: background-image;',
-                #    'transition-duration: 1s;',
-                #    '}',
                 'GtkScale {',
                     'outline-color: transparent;',
                     'outline-offset: 0;',
                     'outline-style: none;',
                     'outline-width: 0;',
-                    '}',
+                '}',
                 'GtkTextView.lrc_tv {',
                     'font-size: {0};'.format(self.conf['lrc-text-size']),
                     'color: {0};'.format(self.conf['lrc-text-color']),
@@ -190,42 +170,41 @@ class App:
                     'border-width: 5;',
                     'background-color: {0};'.format(
                         self.conf['lrc-back-color']),
-                    '}',
+                '}',
                 '.info-label {',
                     'color: rgb(136, 139, 132);',
                     'font-size: 9;',
-                    '}',
+                '}',
                 ])
         else:
             css = '\n'.join([
                 'GtkScrolledWindow.lrc_window {',
                     'transition-property: background-image;',
                     'transition-duration: 1s;',
-                    #'background-repeat: no-repeat;',
-                    #'background-repeat: repeat;',
-                    #'background-position: center;',
-                    '}',
+                '}',
                 'GtkScale {',
                     'outline-color: transparent;',
                     'outline-offset: 0;',
                     'outline-style: none;',
                     'outline-width: 0;',
-                    '}',
+                '}',
                 'GtkTextView.lrc_tv {',
+                    'transition-property: font-size;',
+                    'transition: 500ms ease-in-out;',
                     'font-size: {0}px;'.format(self.conf['lrc-text-size']),
                     'color: {0};'.format(self.conf['lrc-text-color']),
                     'border-radius: 0px 25px 0px 50px;',
                     'border-width: 5px;',
                     'background-color: {0};'.format(
                         self.conf['lrc-back-color']),
-                    '}',
+                '}',
                 '.info-label {',
                     'color: rgb(136, 139, 132);',
                     'font-size: 9px;',
-                    '}',
+                '}',
                 ])
 
-        self.apply_css(self.window, css, overall=True)
+        Widgets.apply_css(self.window, css, overall=True)
 
         settings = Gtk.Settings.get_default()
         settings.props.gtk_application_prefer_dark_theme = \
@@ -250,18 +229,37 @@ class App:
     def on_status_icon_popup_menu(self, status_icon, event_button, 
                                   event_time):
         menu = Gtk.Menu()
+
         show_item = Gtk.MenuItem(label=_('Show App') )
         show_item.connect('activate', self.on_status_icon_show_app_activate)
         menu.append(show_item)
 
-        pause_item = Gtk.MenuItem(label=_('Pause/Resume'))
-        pause_item.connect('activate', self.on_status_icon_pause_activate)
-        menu.append(pause_item)
+        sep_item = Gtk.SeparatorMenuItem()
+        menu.append(sep_item)
+
+        previous_item = Gtk.MenuItem(label=_('Previous Song'))
+        previous_item.connect('activate', self.on_status_icon_prev_activate)
+        menu.append(previous_item)
+
+        play_item = Gtk.MenuItem()
+        play_item.props.related_action = self.player.playback_action
+        menu.append(play_item)
 
         next_item = Gtk.MenuItem(label=_('Next Song'))
         next_item.connect('activate', self.on_status_icon_next_activate)
         menu.append(next_item)
 
+        sep_item = Gtk.SeparatorMenuItem()
+        menu.append(sep_item)
+
+        show_osd_item = Gtk.MenuItem()
+        show_osd_item.props.related_action = self.osdlrc.show_window_action
+        menu.append(show_osd_item)
+
+        lock_osd_item = Gtk.MenuItem()
+        lock_osd_item.props.related_action = self.osdlrc.lock_window_action
+        menu.append(lock_osd_item)
+
         sep_item = Gtk.SeparatorMenuItem()
         menu.append(sep_item)
         
@@ -277,12 +275,18 @@ class App:
     def on_status_icon_show_app_activate(self, menuitem):
         self.window.present()
 
+    def on_status_icon_prev_activate(self, menuitem):
+        self.player.load_prev()
+
     def on_status_icon_pause_activate(self, menuitem):
         self.player.play_pause()
 
     def on_status_icon_next_activate(self, menuitem):
         self.player.load_next()
 
+    def on_status_icon_lock_osd_activate(self, menuitem):
+        self.osdlrc.toggle_lock()
+
     def on_status_icon_quit_activate(self, menuitem):
         self.quit()
 
