@@ -29,12 +29,16 @@ gettext.bindtextdomain('kwplayer', LOCALEDIR)
 gettext.textdomain('kwplayer')
 _ = gettext.gettext
 
+# Check Gtk version <= 3.6
+GTK_LE_36 = (Gtk.MAJOR_VERSION == 3) and (Gtk.MINOR_VERSION <= 6)
+GTK_GE_312 = Gtk.MINOR_VERSION >= 12
+
 APPNAME = _('KW Player')
 VERSION = kuwo.__version__
 HOMEPAGE = 'https://github.com/LiuLang/kwplayer'
 AUTHORS = ['LiuLang <gsushzhsosgsu@gmail.com>', ]
 COPYRIGHT = 'Copyright (c) 2013-2014 LiuLang'
-DESCRIPTION = _('A simple music player on Linux desktop.')
+DESCRIPTION = _('Music player for linux users')
 
 ICON_PATH = os.path.join(PREF, 'kuwo', 'themes', 'default')
 HOME_DIR = os.path.expanduser('~')
@@ -57,15 +61,12 @@ FAV_ARTISTS_JSON = os.path.join(CACHE_DIR, 'fav_artists.json')
 THEME_DIR = os.path.join(PREF, 'kuwo', 'themes', 'default')
 LRC_BACKGROUND_IMG = os.path.join(THEME_DIR, 'lrc-background.jpg')
 
+
 class ShortcutMode:
     NONE = 0
     DEFAULT = 1
     CUSTOM = 2
 
-# Check Gtk version <= 3.6
-GTK_LE_36 = (Gtk.MAJOR_VERSION == 3) and (Gtk.MINOR_VERSION <= 6)
-GTK_GE_312 = Gtk.MINOR_VERSION >= 12
-
 CONF_DIR = os.path.join(HOME_DIR, '.config', 'kuwo')
 _conf_file = os.path.join(CONF_DIR, 'conf.json')
 SHORT_CUT_I18N = {
@@ -89,8 +90,7 @@ _default_conf = {
     'video': 1,  # mp4 high
     'use-status-icon': True,
     'use-notify': False,
-    'use-dark-theme': True,
-    'show-pls': False,
+    'use-dark-theme': False,
     'lrc-text-color': 'rgba(46, 52, 54, 0.999)',
     'lrc-back-color': 'rgba(237, 221, 221, 0.28)',
     'lrc-text-size': 22,
@@ -119,6 +119,17 @@ _default_conf = {
         'Stop': 'XF86AudioStop',
         'Launch': 'XF86AudioMedia',
     },
+
+    'osd-x': 200,
+    'osd-y': 200,
+    'osd-show': False,
+    'osd-locked': False,
+    'osd-style': 'default',
+    'osd-inactivated-color': 'rgba(196, 160, 0, 0.999)',
+    'osd-inactivated-size': 30,
+    'osd-activated-color': 'rgba(32, 74, 135, 0.999)',
+    'osd-activated-size': 40,
+    'osd-background-color': 'rgba(123, 123, 123, 0)',
 }
 
 def check_first():
