@@ -7,6 +7,7 @@
 import os
 import re
 import time
+
 from gi.repository import Gdk
 from gi.repository import GdkPixbuf
 from gi.repository import GdkX11
@@ -15,8 +16,11 @@ from gi.repository import Gtk
 from kuwo import Config
 _ = Config._
 from kuwo.log import logger
+from kuwo import Widgets
 
 LRC_WINDOW, MV_WINDOW = 0, 1
+ADJ_LRC_DELTA = 1000000000 # 1000ms
+
 
 def list_to_time(time_tags):
     mm, ss, ml = time_tags
@@ -27,8 +31,9 @@ def list_to_time(time_tags):
     return int(curr_time * 10 ** 9)
 
 def lrc_parser(lrc_txt):
+    '''将lrc格式的文本分解为一个list'''
     lines = lrc_txt.split('\n')
-    lrc_obj = [(-4, ''), (-3, ''), (-2, ''), ]
+    lrc_obj = [[-4, ''], [-3, ''], [-2, ''], ]
 
     reg_time = re.compile('\[([0-9]{2}):([0-9]{2})(\.[0-9]{1,3})?\]')
     for line in lines:
@@ -42,14 +47,15 @@ def lrc_parser(lrc_txt):
             match = reg_time.match(line, offset)
         content = line[offset:]
         for tag in tags:
-            lrc_obj.append((tag, content))
+            lrc_obj.append([tag, content])
     last_time = lrc_obj[-1][0]
     if last_time <= 0:
         logger.error('lrc_parser(): %s.' % last_time)
         return None
     for i in range(last_time, last_time * 2 + 5, last_time // 4 + 1):
-        lrc_obj.append((i, '', ))
-    return sorted(lrc_obj)
+        lrc_obj.append([i, '', ])
+    return sorted(lrc_obj, key=lambda item: item[0])
+
 
 class Lrc(Gtk.Notebook):
     '''Lyrics tab in notebook.'''
@@ -68,6 +74,7 @@ class Lrc(Gtk.Notebook):
         # lyrics window
         self.lrc_window = Gtk.ScrolledWindow()
         self.lrc_window.get_style_context().add_class('lrc_window')
+        self.lrc_window.props.hscrollbar_policy = Gtk.PolicyType.NEVER
         self.append_page(self.lrc_window, Gtk.Label.new('Lrc'))
 
         self.lrc_buf = Gtk.TextBuffer()
@@ -91,6 +98,7 @@ class Lrc(Gtk.Notebook):
         self.lrc_tv.props.pixels_above_lines = 10
         self.lrc_tv.connect('button-press-event',
                             self.on_lrc_tv_button_pressed)
+        self.lrc_tv.connect('key-press-event', self.on_lrc_tv_key_pressed)
         self.lrc_window.add(self.lrc_tv)
 
         # mv window
@@ -102,16 +110,45 @@ class Lrc(Gtk.Notebook):
 
         self.update_background(self.lrc_default_background)
 
-    def after_init(self):
-        pass
-
     def first(self):
         pass
 
-    def on_lrc_tv_button_pressed(self, widget, event):
-        if event.button == 3:
+    def on_lrc_tv_button_pressed(self, textview, event):
+        if event.button == Gdk.BUTTON_SECONDARY:
             return True
 
+    def on_lrc_tv_key_pressed(self, textview, event):
+        if event.state == Gdk.ModifierType.CONTROL_MASK:
+            state, keyval = event.get_keyval()
+            if keyval == Gdk.KEY_Up:
+                self.adj_lrc_backwad()
+                return True
+            elif keyval == Gdk.KEY_Down:
+                self.adj_lrc_forward()
+                return True
+        return False
+
+    # Open API
+    def adj_lrc_backwad(self):
+        '''前前调整歌词'''
+        if not self.lrc_obj:
+            return
+        length = len(self.lrc_obj)
+        line_num = self.old_line_num - 1
+        while line_num < length:
+            self.lrc_obj[line_num][0] -= ADJ_LRC_DELTA
+            line_num += 1
+
+    def adj_lrc_forward(self):
+        '''前后调整歌词'''
+        if not self.lrc_obj:
+            return
+        length = len(self.lrc_obj)
+        line_num = self.old_line_num
+        while line_num < length:
+            self.lrc_obj[line_num][0] += ADJ_LRC_DELTA
+            line_num += 1
+
     def set_lrc(self, lrc_txt):
         self.update_background(self.lrc_default_background)
         self.old_line_num = 1
@@ -120,8 +157,10 @@ class Lrc(Gtk.Notebook):
         if not lrc_txt:
             self.lrc_buf.set_text(_('No lrc available'))
             self.lrc_obj = None
+            self.app.osdlrc.set_lrc(self.lrc_obj)
             return
         self.lrc_obj = lrc_parser(lrc_txt)
+        self.app.osdlrc.set_lrc(self.lrc_obj)
         if not self.lrc_obj:
             logger.warn('set_lrc(): failed to parse lrc.')
             self.lrc_buf.set_text(_('No lrc available'))
@@ -157,6 +196,8 @@ class Lrc(Gtk.Notebook):
                 line_num += 1
         line_num -= 1
 
+        self.app.osdlrc.sync_lrc(line_num)
+
         iter_start = self.lrc_buf.get_iter_at_line(line_num)
         iter_end = self.lrc_buf.get_iter_at_line(line_num+1)
         self.lrc_buf.apply_tag(self.highlighted_tag, iter_start, iter_end)
@@ -187,9 +228,8 @@ class Lrc(Gtk.Notebook):
                 "background-image: url('{0}');".format(self.lrc_background),
             '}',
         ])
-        new_provider = self.app.apply_css(self.lrc_window, css,
-                                          old_provider=self.old_provider)
-        self.old_provider = new_provider
+        self.old_provider = Widgets.apply_css(self.lrc_window, css,
+                                              old_provider=self.old_provider)
 
     def update_highlighted_tag(self):
         fore_rgba = Gdk.RGBA()
