@@ -449,8 +449,7 @@ class PlayList(Gtk.Box):
         self.load_playlists()
         # dump playlists to dist every 5 minites
         GLib.timeout_add(300000, self.dump_playlists)
-        if self.app.conf['show-pls']:
-            self.app.popup_page(self.app_page)
+        self.app.popup_page(self.app_page)
         return False
 
     def dump_playlists(self):
@@ -879,6 +878,7 @@ class PlayList(Gtk.Box):
         self.playlist_advice_disname = disname
 
     def on_advice_menu_item_activated(self, advice_item):
+        '''新建一个播放列表'''
         list_name = str(time.time())
         tooltip = Widgets.escape(self.playlist_advice_disname)
         self.liststore_left.append(
@@ -893,6 +893,7 @@ class PlayList(Gtk.Box):
         self.add_songs_to_playlist(songs, list_name)
 
     def popup_playlist_menu(self, button, songs):
+        '''弹出选择播放列表的菜单'''
         menu = self.playlist_menu
         while menu.get_children():
             menu.remove(menu.get_children()[0])
